@@ -16,17 +16,15 @@ has ff_dir      => ( is => 'lazy', isa => Str, init_arg => undef );
 has ff_bin_path => ( is => 'lazy', isa => Str, init_arg => undef );
 
 our $CFG = {
-    SELENIUM => {
-        SELENIUM_VER    => undef,
-        FF_VER          => undef,
-        PORT            => 4444,
-        LINUX_XDISPLAY  => 20,
-        USER_EXTENSIONS => q[],
-        FF_EXTENSIONS   => {
-            firebug   => 'https://addons.mozilla.org/firefox/downloads/latest/1843/addon-1843-latest.xpi',
-            firexpath => 'https://addons.mozilla.org/firefox/downloads/latest/11900/addon-11900-latest.xpi',
-            noscript  => 'https://addons.mozilla.org/firefox/downloads/latest/722/addon-722-latest.xpi',
-        }
+    selenium_ver    => undef,
+    ff_ver          => undef,
+    port            => 4444,
+    linux_xdisplay  => 20,
+    user_extensions => q[],
+    ff_extensions   => {
+        firebug   => 'https://addons.mozilla.org/firefox/downloads/latest/1843/addon-1843-latest.xpi',
+        firexpath => 'https://addons.mozilla.org/firefox/downloads/latest/11900/addon-11900-latest.xpi',
+        noscript  => 'https://addons.mozilla.org/firefox/downloads/latest/722/addon-722-latest.xpi',
     }
 };
 
@@ -40,7 +38,7 @@ around CLI => sub ( $orig, $self ) {
 };
 
 sub _build_selenium_ver ($self) {
-    return $self->cfg->{SELENIUM}->{SELENIUM_VER} // $ENV->dist('Pcore-Selenium')->cfg->{SELENIUM}->{SELENIUM_VER};
+    return $self->cfg->{selenium_ver} // $ENV->dist('Pcore-Selenium')->cfg->{selenium_ver};
 }
 
 sub _build_selenium_uri ($self) {
@@ -50,7 +48,7 @@ sub _build_selenium_uri ($self) {
 }
 
 sub _build_ff_ver ($self) {
-    return $self->cfg->{SELENIUM}->{FF_VER} // $ENV->dist('Pcore-Selenium')->cfg->{SELENIUM}->{FF_VER};
+    return $self->cfg->{ff_ver} // $ENV->dist('Pcore-Selenium')->cfg->{ff_ver};
 }
 
 sub _build_alien_bin_path ($self) {
@@ -122,13 +120,13 @@ sub _build_ff_extensions ($self) {
 
     my $cv = AE::cv;
 
-    for my $ext ( sort keys $self->cfg->{SELENIUM}->{FF_EXTENSIONS}->%* ) {
+    for my $ext ( sort keys $self->cfg->{ff_extensions}->%* ) {
         $self->_appx_report_info(qq[Downloading: $ext]);
 
         $cv->begin;
 
         P->http->get(
-            $self->cfg->{SELENIUM}->{FF_EXTENSIONS}->{$ext},
+            $self->cfg->{ff_extensions}->{$ext},
             buf_size    => 1,
             on_progress => 1,
             on_finish   => sub ($res) {
@@ -164,10 +162,10 @@ sub _cmd ($self) {
     # Please note that the "browserTimeout" is intended as a backup timeout mechanism when the ordinary timeout mechanism fails, which should be used mostly in grid/server environments to ensure that crashed/lost processes do not stay around for too long, polluting the runtime environment.
 
     my $cmd = q[java -Xrs -jar "] . $self->alien_bin_path . q["];
-    $cmd .= q[ -port ] . $self->cfg->{SELENIUM}->{PORT};
+    $cmd .= q[ -port ] . $self->cfg->{port};
     $cmd .= q[ -timeout ] . ( 5 * 60 );
     $cmd .= q[ -browserTimeout ] . ( 6 * 60 );
-    $cmd .= q[ -userExtensions ] . $self->cfg->{SELENIUM}->{USER_EXTENSIONS} if $self->cfg->{SELENIUM}->{USER_EXTENSIONS};    # indicates a JavaScript file that will beloaded into selenium
+    $cmd .= q[ -userExtensions ] . $self->cfg->{user_extensions} if $self->cfg->{user_extensions};    # indicates a JavaScript file that will beloaded into selenium
     $cmd .= q[ -ensureCleanSession];
     $cmd .= q[ -trustAllSSLCertificates];
     $cmd .= q[ -proxyInjectionMode];
@@ -186,11 +184,9 @@ around _build_cfg => sub ( $orig, $self ) {
 
 around _create_local_cfg => sub ( $orig, $self ) {
     my $local_cfg = {
-        SELENIUM => {
-            SELENIUM_VER => $self->cfg->{SELENIUM}->{SELENIUM_VER},
-            FF_VER       => $self->cfg->{SELENIUM}->{FF_VER},
-            PORT         => $self->cfg->{SELENIUM}->{PORT},
-        }
+        selenium_ver => $self->cfg->{selenium_ver},
+        ff_ver       => $self->cfg->{ff_ver},
+        port         => $self->cfg->{port},
     };
 
     return P->hash->merge( $self->$orig, $local_cfg );
@@ -216,7 +212,7 @@ sub alien_proc ($self) {
         exit 0;
     }
     else {
-        exec q[xvfb-run -n ] . $self->cfg->{SELENIUM}->{LINUX_XDISPLAY} . q[ -l -s "-fp /usr/share/X11/fonts/misc -screen 0 1024x768x24" ] . $self->_cmd() or die;
+        exec q[xvfb-run -n ] . $self->cfg->{linux_xdisplay} . q[ -l -s "-fp /usr/share/X11/fonts/misc -screen 0 1024x768x24" ] . $self->_cmd() or die;
     }
 
     return;
@@ -229,9 +225,9 @@ sub alien_proc ($self) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 125                  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
+## |    3 | 123                  | References::ProhibitDoubleSigils - Double-sigil dereference                                                    |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 145                  | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
+## |    3 | 143                  | ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
